@@ -22,37 +22,46 @@ sys.path.insert(0, ROOT)
 sys.path.insert(0, BASE_DIR)
 
 
+# TODO(stephenfin): This looks like something that pbr's autodoc integration
+# could be doing for us. Investigate.
+
 def gen_ref(ver, title, names):
-    refdir = os.path.join(BASE_DIR, "ref")
+    refdir = os.path.join(BASE_DIR, "reference", "api")
     pkg = "novaclient"
     if ver:
         pkg = "%s.%s" % (pkg, ver)
         refdir = os.path.join(refdir, ver)
     if not os.path.exists(refdir):
         os.makedirs(refdir)
-    idxpath = os.path.join(refdir, "index.rst")
-    with open(idxpath, "w") as idx:
-        idx.write(("%(title)s\n"
-                   "%(signs)s\n"
-                   "\n"
-                   ".. toctree::\n"
-                   "   :maxdepth: 1\n"
-                   "\n") % {"title": title, "signs": "=" * len(title)})
-        for name in names:
-            idx.write("   %s\n" % name)
-            rstpath = os.path.join(refdir, "%s.rst" % name)
-            with open(rstpath, "w") as rst:
-                rst.write(("%(title)s\n"
-                           "%(signs)s\n"
-                           "\n"
-                           ".. automodule:: %(pkg)s.%(name)s\n"
-                           "   :members:\n"
-                           "   :undoc-members:\n"
-                           "   :show-inheritance:\n"
-                           "   :noindex:\n")
-                          % {"title": name.capitalize(),
-                             "signs": "=" * len(name),
-                             "pkg": pkg, "name": name})
+
+    # we don't want to write index files for top-level directories - only
+    # sub-directories
+    if ver:
+        idxpath = os.path.join(refdir, "index.rst")
+        with open(idxpath, "w") as idx:
+            idx.write(("%(title)s\n"
+                       "%(signs)s\n"
+                       "\n"
+                       ".. toctree::\n"
+                       "   :maxdepth: 1\n"
+                       "\n") % {"title": title, "signs": "=" * len(title)})
+            for name in names:
+                idx.write("   %s\n" % name)
+
+    for name in names:
+        rstpath = os.path.join(refdir, "%s.rst" % name)
+        with open(rstpath, "w") as rst:
+            rst.write(("%(title)s\n"
+                       "%(signs)s\n"
+                       "\n"
+                       ".. automodule:: %(pkg)s.%(name)s\n"
+                       "   :members:\n"
+                       "   :undoc-members:\n"
+                       "   :show-inheritance:\n"
+                       "   :noindex:\n")
+                      % {"title": name.capitalize(),
+                         "signs": "=" * len(name),
+                         "pkg": pkg, "name": name})
 
 
 def get_module_names():
@@ -70,7 +79,10 @@ gen_ref("v2", "Version 2 API", sorted(get_module_names()))
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc', 'oslosphinx']
+extensions = [
+    'sphinx.ext.autodoc',
+    'openstackdocstheme',
+]
 
 autoclass_content = 'both'
 
@@ -83,7 +95,10 @@ source_suffix = '.rst'
 # The master toctree document.
 master_doc = 'index'
 
-# General information about the project.
+# openstackdocstheme options
+repository_name = 'openstack/python-novaclient'
+bug_project = 'python-novaclient'
+bug_tag = 'doc'
 project = 'python-novaclient'
 copyright = 'OpenStack Contributors'
 
@@ -105,16 +120,19 @@ pygments_style = 'sphinx'
 
 # The theme to use for HTML and HTML Help pages.  Major themes that come with
 # Sphinx are currently 'default' and 'sphinxdoc'.
-html_theme = 'default'
+html_theme = 'openstackdocs'
 
-# Output file base name for HTML help builder.
-htmlhelp_basename = 'python-novaclientdoc'
+# -- Options for openstackdocstheme -------------------------------------------
+
+repository_name = 'openstack/python-novaclient'
+bug_project = 'python-novaclient'
+bug_tag = ''
 
 # -- Options for manual page output ------------------------------------------
 
 # One entry per manual page. List of tuples
 # (source start file, name, description, authors, manual section).
 man_pages = [
-    ('man/nova', 'nova', 'OpenStack Nova command line client',
+    ('cli/nova', 'nova', 'OpenStack Nova command line client',
      ['OpenStack Contributors'], 1),
 ]
