@@ -24,6 +24,32 @@ class UnsupportedVersion(Exception):
     pass
 
 
+class UnsupportedConsoleType(Exception):
+    """Indicates that the user is trying to use an unsupported
+    console type when retrieving console urls of servers.
+    """
+    def __init__(self, console_type):
+        self.message = 'Unsupported console_type "%s"' % console_type
+
+
+class UnsupportedAttribute(AttributeError):
+    """Indicates that the user is trying to transmit the argument to a method,
+    which is not supported by selected version.
+    """
+
+    def __init__(self, argument_name, start_version, end_version=None):
+        if end_version:
+            self.message = (
+                "'%(name)s' argument is only allowed for microversions "
+                "%(start)s - %(end)s." % {"name": argument_name,
+                                          "start": start_version,
+                                          "end": end_version})
+        else:
+            self.message = (
+                "'%(name)s' argument is only allowed since microversion "
+                "%(start)s." % {"name": argument_name, "start": start_version})
+
+
 class CommandError(Exception):
     pass
 
@@ -36,15 +62,6 @@ class NoUniqueMatch(Exception):
     pass
 
 
-class AuthSystemNotFound(Exception):
-    """When the user specify a AuthSystem but not installed."""
-    def __init__(self, auth_system):
-        self.auth_system = auth_system
-
-    def __str__(self):
-        return "AuthSystemNotFound: %s" % repr(self.auth_system)
-
-
 class NoTokenLookupException(Exception):
     """This form of authentication does not support looking up
        endpoints from an existing token.
@@ -77,9 +94,15 @@ class ConnectionRefused(Exception):
         return "ConnectionRefused: %s" % repr(self.response)
 
 
-class InstanceInErrorState(Exception):
-    """Instance is in the error state."""
-    pass
+class ResourceInErrorState(Exception):
+    """Resource is in the error state."""
+
+    def __init__(self, obj):
+        msg = "`%s` resource is in the error state" % obj.__class__.__name__
+        fault_msg = getattr(obj, "fault", {}).get("message")
+        if fault_msg:
+            msg += "due to '%s'" % fault_msg
+        self.message = "%s." % msg
 
 
 class VersionNotFoundForAPIMethod(Exception):
@@ -270,9 +293,21 @@ def from_response(response, body, url, method=None):
         details = "n/a"
 
         if hasattr(body, 'keys'):
-            error = body[list(body)[0]]
-            message = error.get('message')
-            details = error.get('details')
+            # NOTE(mriedem): WebOb<1.6.0 will return a nested dict structure
+            # where the error keys to the message/details/code. WebOb>=1.6.0
+            # returns just a response body as a single dict, not nested,
+            # so we have to handle both cases (since we can't trust what we're
+            # given with content_type: application/json either way.
+            if 'message' in body:
+                # WebOb 1.6.0 case
+                message = body.get('message')
+                details = body.get('details')
+            else:
+                # WebOb<1.6.0 where we assume there is a single error message
+                # key to the body that has the message and details.
+                error = body[list(body)[0]]
+                message = error.get('message')
+                details = error.get('details')
 
         kwargs['message'] = message
         kwargs['details'] = details
