@@ -10,8 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import tempest_lib.cli.base
-
 from novaclient.tests.functional import base
 from novaclient.tests.functional.v2 import fake_crypto
 from novaclient.tests.functional.v2.legacy import test_keypairs
@@ -46,36 +44,11 @@ class TestKeypairsNovaClientV22(test_keypairs.TestKeypairsNovaClient):
         self.assertIn('x509', keypair)
 
 
-class TestKeypairsNovaClientV210(base.ClientTestBase):
-    """Keypairs functional tests for v2.10 nova-api microversion.
-    """
+class TestKeypairsNovaClientV210(base.TenantTestBase):
+    """Keypairs functional tests for v2.10 nova-api microversion."""
 
     COMPUTE_API_VERSION = "2.10"
 
-    def setUp(self):
-        super(TestKeypairsNovaClientV210, self).setUp()
-        user_name = self.name_generate("v2.10")
-        password = "password"
-        user = self.cli_clients.keystone(
-            "user-create --name %(name)s --pass %(pass)s --tenant %(tenant)s" %
-            {"name": user_name, "pass": password,
-             "tenant": self.cli_clients.tenant_name})
-        self.user_id = self._get_value_from_the_table(user, "id")
-        self.addCleanup(self.cli_clients.keystone,
-                        "user-delete %s" % self.user_id)
-        self.cli_clients_2 = tempest_lib.cli.base.CLIClient(
-            username=user_name,
-            password=password,
-            tenant_name=self.cli_clients.tenant_name,
-            uri=self.cli_clients.uri,
-            cli_dir=self.cli_clients.cli_dir)
-
-    def another_nova(self, action, flags='', params='', fail_ok=False,
-                     endpoint_type='publicURL', merge_stderr=False):
-        flags += " --os-compute-api-version %s " % self.COMPUTE_API_VERSION
-        return self.cli_clients_2.nova(action, flags, params, fail_ok,
-                                       endpoint_type, merge_stderr)
-
     def test_create_and_list_keypair(self):
         name = self.name_generate("v2_10")
         self.nova("keypair-add %s --user %s" % (name, self.user_id))
@@ -118,3 +91,30 @@ class TestKeypairsNovaClientV210(base.ClientTestBase):
         self.assertRaises(
             ValueError,
             self._get_column_value_from_single_row_table, output, "Name")
+
+
+class TestKeypairsNovaClientV235(base.TenantTestBase):
+    """Keypairs functional tests for v2.35 nova-api microversion."""
+
+    COMPUTE_API_VERSION = "2.35"
+
+    def test_create_and_list_keypair_with_marker_and_limit(self):
+        names = []
+        for i in range(3):
+            names.append(self.name_generate("v2_35"))
+            self.nova("keypair-add %s --user %s" % (names[i], self.user_id))
+            self.addCleanup(self.another_nova, "keypair-delete %s" % names[i])
+
+        # sort keypairs before pagination
+        names = sorted(names)
+
+        # list only one keypair after the first
+        output_1 = self.another_nova("keypair-list --limit 1 --marker %s" %
+                                     names[0])
+        output_2 = self.nova("keypair-list --limit 1 --marker %s --user %s" %
+                             (names[0], self.user_id))
+        self.assertEqual(output_1, output_2)
+        # it should be table with only one second key-pair
+        self.assertEqual(
+            names[1], self._get_column_value_from_single_row_table(output_1,
+                                                                   "Name"))
