@@ -21,6 +21,10 @@ places where actual behavior differs from the spec.
 
 from novaclient import base
 
+# fake request id
+FAKE_REQUEST_ID = 'req-3fdea7c2-e3e3-48b5-a656-6b12504c49a1'
+FAKE_REQUEST_ID_LIST = [FAKE_REQUEST_ID]
+
 
 def assert_has_keys(dict, required=None, optional=None):
     required = required or []
@@ -74,13 +78,19 @@ class FakeClient(object):
                     }, pos=4)
         """
         expected = (method, url)
-        called = self.client.callstack[pos][0:2]
 
         assert self.client.callstack, \
             "Expected %s %s but no calls were made." % expected
 
+        called = self.client.callstack[pos][0:2]
+
         assert expected == called, \
-            'Expected %s %s; got %s %s' % (expected + called)
+            ('\nExpected: %(expected)s'
+             '\nActual: %(called)s'
+             '\nCall position: %(pos)s'
+             '\nCalls:\n%(calls)s' %
+             {'expected': expected, 'called': called, 'pos': pos,
+              'calls': '\n'.join(str(c) for c in self.client.callstack)})
 
         if body is not None:
             if self.client.callstack[pos][2] != body:
